@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2016-06-02'; # DATE
-our $VERSION = '0.31'; # VERSION
+our $DATE = '2016-09-25'; # DATE
+our $VERSION = '0.32'; # VERSION
 
 use 5.010001;
 use strict;
@@ -46,6 +46,8 @@ has code_after_end => (is=>'rw');
 has skip_format => (is=>'rw');
 has use_utf8 => (is=>'rw');
 has allow_prereq => (is=>'rw');
+has per_arg_json => (is=>'rw');
+has per_arg_yaml => (is=>'rw');
 
 sub mvp_multivalue_args { qw(build_load_modules load_modules code_before_instantiate_cmdline code_after_end config_filename config_dirs allow_prereq) }
 
@@ -150,6 +152,8 @@ sub munge_files {
             skip_format => $self->skip_format ? 1:0,
             use_utf8 => $self->use_utf8,
             (allow_prereq => $self->allow_prereq) x !!$self->allow_prereq,
+            (per_arg_json => $self->per_arg_json) x !!defined($self->per_arg_json),
+            (per_arg_yaml => $self->per_arg_yaml) x !!defined($self->per_arg_yaml),
         );
         #use DD; dd \%gen_args;
         $res = gen_pericmd_script(%gen_args);
@@ -241,7 +245,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.31 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2016-06-02.
+This document describes version 0.32 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2016-09-25.
 
 =head1 SYNOPSIS
 
@@ -409,6 +413,14 @@ Passed to Perinci::CmdLine object construction code.
 
 Will be passed to Perinci::CmdLine::Gen backend.
 
+=head2 per_arg_json => bool
+
+Will be passed to Perinci::CmdLine::Gen backend.
+
+=head2 per_arg_yaml => bool
+
+Will be passed to Perinci::CmdLine::Gen backend.
+
 =head1 CONFIGURATION (OTHER)
 
 =head2 build_load_modules => array[str]
